import sys
sys.path.insert(1, '../../../modules/')

import logging
LOG_FORMAT = ('%(levelname) -5s %(asctime)s %(name)s:%(funcName) -35s %(lineno) -5d:  %(message)s')
logging.basicConfig(filename='trace-retrieval.log', level=logging.WARNING, format=LOG_FORMAT)
LOGGER = logging.getLogger(__name__)

import connexion
from messaging.MessageReceiver import MessageReceiver
from messaging.MessageSender import MessageSender

message_sender = None

# init message handler
def message_received_callback(channel, method, properties, body):
    print(f"### Received: {body}")
    # channel.basic_ack(delivery_tag=method.delivery_tag)
    message_sender.send('rest-gateway', str(body) + ' (sent from trace-retrieval-microservice)', 'rest-gateway')

# load swagger config 
app = connexion.App(__name__, specification_dir='configs/')
app.add_api('swagger.yml')

@app.route('/', methods=['GET'])
def api_root():
    return 'Endpoint of trace-retrieval-microservice!'

# start app
if __name__ == '__main__':
    message_rec = MessageReceiver(exchange_name='inhub', exchange_type='direct', queue_name='trace-retrieval', auto_ack=True)
    message_rec.start(message_received_callback)

    message_sender = MessageSender()
    message_sender.connect()
    message_sender.create_exchange('rest-gateway', 'direct')

    app.run(host='0.0.0.0', port=5000, debug=True, use_reloader=False) # disable reloader so only subscribed once to rabbitmq
